
PyXMake - Cross-plattform build environment
===========================================


.. only:: html

    :Release: |version|
    :Date: |today| 
    :Author: Falk Heinecke, Marc Garbade


====================
Summary and Features
====================
    
=======
Contact 
=======

- PyXMake (Falk Heinecke, Marc Garbade)

========
Contents
========

.. toctree::
   :maxdepth: 2
   
   pyx_core/core.rst   
   
   
   


